Crate reratui_panic

Crate reratui_panic 

Functions

catch_panic
Executes a closure and catches any panics that occur, returning a Result.
setup_panic_handler
Sets up a custom panic hook for the application with advanced features.
spawn_catch_panic
Spawns a new asynchronous task and catches any panics that occur within it.