Functions
- catch_
panic - Executes a closure and catches any panics that occur, returning a Result.
- setup_
panic_ handler - Sets up a custom panic hook for the application with advanced features.
- spawn_
catch_ panic - Spawns a new asynchronous task and catches any panics that occur within it.