pub fn spawn_catch_panic<F>(future: F) -> JoinHandle<F::Output> ⓘExpand description
Spawns a new asynchronous task and catches any panics that occur within it.
If a panic occurs, it will be caught by the custom panic hook.
pub fn spawn_catch_panic<F>(future: F) -> JoinHandle<F::Output> ⓘSpawns a new asynchronous task and catches any panics that occur within it.
If a panic occurs, it will be caught by the custom panic hook.